*****************************
API documentation: exa-common
*****************************

:Version: |version|
:Date: |today|

This documentation describes the common library of the Experiment Automation (**EXA**) project.
``exa-common`` contains classes and functions that are shared by ``EXA``, ``Cortex`` and ``Station Control``.


Contents
========

.. toctree::
   :maxdepth: 2

   API
   Changelog <changelog>
   License <license>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
